@@ -430,6 +430,22 @@ dev_dependencies:
       r#"name: 'NativeLibrary'
 description: 'Auto generated bindings for Dart types'
 output: './lib/src/ffi_bindings.dart'
+sort: true
+enums:
+  include:
+    - __none__
+macros:
+  include:
+    - __none__
+structs:
+  include:
+    - __none__
+unions:
+  include:
+    - __none__
+unnamed-enums:
+  include:
+    - __none__
 headers:
   entry-points:
     - 'lib/src/*/*.h'
@@ -470,9 +486,7 @@ headers:
  */
 #include <stdint.h>
 
-typedef int TaskHandle;
-
-int32_t membrane_cancel_membrane_task(const TaskHandle *task_handle);
+int32_t membrane_cancel_membrane_task(const int32_t *task_handle);
 "#;
 
     let mut buffer =
@@ -613,7 +627,7 @@ class {class_name}ApiError implements Exception {{
 
 @immutable
 class {class_name}Api {{
-  static final _log = Logger('membrane');
+  static final _log = Logger('membrane.{ns}');
   const {class_name}Api();
 "#,
       ns = &namespace,
@@ -668,7 +682,7 @@ impl Function {
   }
   pub fn c_signature(&mut self) -> &mut Self {
     self.output += format!(
-      "TaskHandle *{extern_c_fn_name}(int64_t port{extern_c_fn_types});",
+      "int32_t *{extern_c_fn_name}(int64_t port{extern_c_fn_types});",
       extern_c_fn_name = self.extern_c_fn_name,
       extern_c_fn_types = if self.extern_c_fn_types.is_empty() {
         String::new()
